==> shell-0.2.2.jar: project.clj <==
(defproject org.ozias.cljlibs/shell "0.2.2"
  :description "Clojure Shell Utilities"
  :url "https://github.com/CraZySacX/shell"
  :license {:name "MIT"
            :url "http://opensource.org/licenses/MIT"}
  :dependencies [[me.raynes/conch "0.6.0"]
                 [org.clojure/clojure "1.6.0"]
                 [org.ozias.cljlibs/utils "0.1.7"]]
  :profiles {:dev {:source-paths ["dev"]
                   :dependencies [[midje "1.6.3"
                                   :exclusions [org.clojure/clojure]]
                                  [org.clojure/tools.namespace "0.2.4"]
                                  [org.ozias.cljlibs/scm "0.1.3"]]
                   :plugins [[codox "0.6.8"]
                             [lein-midje "3.1.3"]
                             [org.ozias.plugins/lein-git-version "1.1.3"]]
                   :aliases {"package" ["do" "clean," "install"]
                             "slamhound" ["run" "-m" "slam.hound"]
                             "chk" ["do"
                                    "archaic" "upgrade,"
                                    "slamhound" "src/,"
                                    "slamhound" "test/,"
                                    "eastwood" "{:namespaces [:source-paths]},"
                                    "kibit,"
                                    "bikeshed" "-v,"
                                    "check,"
                                    "midje"]
                             "most" ["do" "clean," "doc," "chk," "package"]
                             "dep" ["do" "deploy," "deploy" "clojars"]
                             "all" ["do" "most," "dep"]}}}
  :jvm-opts ["-Xms1024m" "-Xmx1024m"]
  :deploy-repositories [["snapshots" 
                         {:url
                          "http://www.ozias.net/artifactory/libs-snapshot-local"
                          :creds :gpg}]
                        ["releases"
                         {:url
                          "http://www.ozias.net/artifactory/libs-release-local"
                          :creds :gpg}]]
  :scm {:name "git"
         :url "https://github.com/CraZySacX/shell"}
  :codox {:output-dir "api"
          :exclude [org.ozias.cljlibs.shell.version]
          :src-dir-uri "http://github.com/CraZySacX/shell/blob/0.2.2/"
          :src-linenum-anchor-prefix "L"}
  :manifest {"Implementation-Version" "0.2.2"}
  :git-version {:file {:assoc-in-keys [[:manifest "Implementation-Version"]]}})

==> shell-0.2.2-20140422.183610-1.jar: project.clj <==
(defproject org.ozias.cljlibs/shell "0.2.2-SNAPSHOT"
  :description "Clojure Shell Utilities"
  :url "https://github.com/CraZySacX/shell"
  :license {:name "MIT"
            :url "http://opensource.org/licenses/MIT"}
  :dependencies [[me.raynes/conch "0.6.0"]
                 [org.clojure/clojure "1.6.0"]
                 [org.ozias.cljlibs/utils "0.1.6"]]
  :profiles {:dev {:source-paths ["dev"]
                   :dependencies [[midje "1.6.3"
                                   :exclusions [org.clojure/clojure]]
                                  [org.clojure/tools.namespace "0.2.4"]
                                  [org.ozias.cljlibs/scm "0.1.3"]]
                   :plugins [[codox "0.6.7"]
                             [lein-midje "3.1.3"]
                             [org.ozias.plugins/lein-git-version "1.1.3"]]
                   :aliases {"package" ["do" "clean," "install"]
                             "slamhound" ["run" "-m" "slam.hound"]
                             "chk" ["do"
                                    "slamhound,"
                                    "eastwood" "{:namespaces [:source-paths]},"
                                    "kibit,"
                                    "bikeshed" "-v,"
                                    "check,"
                                    "archaic" "upgrade,"
                                    "midje"]
                             "most" ["do" "clean," "doc," "chk," "package"]
                             "dep" ["do" "deploy," "deploy" "clojars"]
                             "all" ["do" "most," "dep"]}}}
  :jvm-opts ["-Xms1024m" "-Xmx1024m"]
  :deploy-repositories [["snapshots" 
                         {:url
                          "http://www.ozias.net/artifactory/libs-snapshot-local"
                          :creds :gpg}]
                        ["releases"
                         {:url
                          "http://www.ozias.net/artifactory/libs-release-local"
                          :creds :gpg}]]
  :scm {:name "git"
         :url "https://github.com/CraZySacX/shell"}
  :codox {:output-dir "api"
          :exclude [org.ozias.cljlibs.shell.version]
          :src-dir-uri "http://github.com/CraZySacX/shell/blob/master/"
          :src-linenum-anchor-prefix "L"}
  :manifest {"Implementation-Version" "0.2.2-SNAPSHOT"}
  :git-version {:file {:assoc-in-keys [[:manifest "Implementation-Version"]]}})
